@@ -22,16 +22,18 @@
 #include <Arduino.h>
 
 #define VERSION_MAJOR 0
-#define VERSION_MINOR 9
-#define VERSION_PATCH 1
+#define VERSION_MINOR 10
+#define VERSION_PATCH 0
 
 #if defined(ARDUINO_SAM_DUE)
 # define OCTAVE_COMMS_PORT SERIAL_PORT_MONITOR
 #elif defined(SERIAL_PORT_USBVIRTUAL)
   // sparkfun samed21 dev/mini
 # define OCTAVE_COMMS_PORT SERIAL_PORT_USBVIRTUAL
-#else
+#elif defined(SERIAL_PORT_MONITOR)
 # define OCTAVE_COMMS_PORT SERIAL_PORT_MONITOR
+#else
+# define OCTAVE_COMMS_PORT Serial
 #endif
 
 class OctaveLibraryBase
