@@ -1,4 +1,4 @@
-## Copyright (C) 2019 John Donoghue <john.donoghue@ieee.org>
+## Copyright (C) 2019-2020 John Donoghue <john.donoghue@ieee.org>
 ## 
 ## This program is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
@@ -14,124 +14,124 @@
 ## along with this program.  If not, see
 ## <https://www.gnu.org/licenses/>.
 
-## -*- texinfo -*- 
-## @deftypefn {} {} arduinosensor.DS1307
-## DS1307 realtime clock sensor
-## @end deftypefn
-##
-## @subheading Methods
-## @deftypefn {} {@var{obj} =} DS1307(@var{arObj})
-## @deftypefnx {} {@var{obj} =} DS1307(@var{arObj}, @var{propertyname, propertyvalue} ....)
-## Constructor to create DS1307 sensor
-## @subsubheading Inputs
-## @var{arObj} - the arduino parent object
-##
-## @var{propertyname, propertyvalue} - optional property name, value pairs.
-## Current known properties are:
-## Current properties are:
-## @table @asis
-## @item i2caddress
-## I2C address of the DS1307 (default 0x68)
-## @end table
-##
-## @subsubheading Outputs
-## @var{obj} - created DS1307 object
-##
-## @subsubheading Example
-## @example
-## @code {
-## a = arduino()
-## rtc = arduinosensor.DS1307(a)
-## }
-## @end example
-## @end deftypefn
-##
-## @deftypefn {} {@var{date} =} clock(@var{dsObj})
-## @deftypefnx {} {} clock(@var{dsObj}, @var{date})
-## Get/set the DS1307 clock
-##
-## @subsubheading Inputs
-## @var{dsObj} - the ds1307 object
-##
-## @var{date} - a date vector in same format as datevec and clock
-##
-## @subsubheading Outputs
-## @var{date} - a date vector in same format as datevec and clock
-##
-## @subsubheading Example
-## @example
-## @code {
-## a = arduino()
-## rtc = arduinosensor.DS1307(a)
-## # get and display rtc time as a date string
-## datestr(rtc.clock)
-## }
-## @end example
-## @seealso{datevec}
-## @end deftypefn
-##
-## @deftypefn {} {@var{ctrl} =} control(@var{dsObj})
-## @deftypefnx {} {} control(@var{dsObj}, @var{ctrl})
-## Get/set the DS1307 clock
-##
-## @subsubheading Inputs
-## @var{dsObj} - the ds1307 object
-##
-## @var{ctrl} - a structure containing the control bit fields.
-##
-## @subsubheading Outputs
-## @var{ctrl} - a structure containing the control bit fields.
-##
-## Control structure fields are:
-## Current properties are:
-## @table @asis
-## @item out
-## Out bit in the control register
-## @item sqwe
-## Square wave enable bit in control register
-## @item rs
-## The combined RS0, RS1 value
-## @end table
-##
-## @end deftypefn
-##
-## @deftypefn {} {@var{YN} =} isstarted(@var{dsObj})
-## Get whether the RTC clock is currently counting time
-##
-## @subsubheading Inputs
-## @var{dsObj} - the ds1307 object
-##
-## @subsubheading Outputs
-## @var{YN} - returns true if the RTC is counting
-##
-## @seealso{start, stop}
-## @end deftypefn
-##
-## @deftypefn {} {} start(@var{dsObj})
-## Start the RTC counting
-##
-## @subsubheading Inputs
-## @var{dsObj} - the ds1307 object
-##
-## @subsubheading Outputs
-## None
-##
-## @seealso{datevec}
-## @end deftypefn
-##
-## @deftypefn {} {} stop(@var{dsObj})
-## Stop the RTC counting
-##
-## @subsubheading Inputs
-## @var{dsObj} - the ds1307 object
-##
-## @subsubheading Outputs
-## None
-##
-## @seealso{datevec}
-## @end deftypefn
-
 classdef DS1307 < handle
+  ## -*- texinfo -*- 
+  ## @deftypefn {} {} arduinosensor.DS1307
+  ## DS1307 realtime clock sensor
+  ## @end deftypefn
+  ##
+  ## @subheading Methods
+  ## @deftypefn {} {@var{obj} =} DS1307(@var{arObj})
+  ## @deftypefnx {} {@var{obj} =} DS1307(@var{arObj}, @var{propertyname, propertyvalue} ....)
+  ## Constructor to create DS1307 sensor
+  ## @subsubheading Inputs
+  ## @var{arObj} - the arduino parent object
+  ##
+  ## @var{propertyname, propertyvalue} - optional property name, value pairs.
+  ## Current known properties are:
+  ## Current properties are:
+  ## @table @asis
+  ## @item i2caddress
+  ## I2C address of the DS1307 (default 0x68)
+  ## @end table
+  ##
+  ## @subsubheading Outputs
+  ## @var{obj} - created DS1307 object
+  ##
+  ## @subsubheading Example
+  ## @example
+  ## @code {
+  ## a = arduino()
+  ## rtc = arduinosensor.DS1307(a)
+  ## }
+  ## @end example
+  ## @end deftypefn
+  ##
+  ## @deftypefn {} {@var{date} =} clock(@var{dsObj})
+  ## @deftypefnx {} {} clock(@var{dsObj}, @var{date})
+  ## Get/set the DS1307 clock
+  ##
+  ## @subsubheading Inputs
+  ## @var{dsObj} - the ds1307 object
+  ##
+  ## @var{date} - a date vector in same format as datevec and clock
+  ##
+  ## @subsubheading Outputs
+  ## @var{date} - a date vector in same format as datevec and clock
+  ##
+  ## @subsubheading Example
+  ## @example
+  ## @code {
+  ## a = arduino()
+  ## rtc = arduinosensor.DS1307(a)
+  ## # get and display rtc time as a date string
+  ## datestr(rtc.clock)
+  ## }
+  ## @end example
+  ## @seealso{datevec}
+  ## @end deftypefn
+  ##
+  ## @deftypefn {} {@var{ctrl} =} control(@var{dsObj})
+  ## @deftypefnx {} {} control(@var{dsObj}, @var{ctrl})
+  ## Get/set the DS1307 clock
+  ##
+  ## @subsubheading Inputs
+  ## @var{dsObj} - the ds1307 object
+  ##
+  ## @var{ctrl} - a structure containing the control bit fields.
+  ##
+  ## @subsubheading Outputs
+  ## @var{ctrl} - a structure containing the control bit fields.
+  ##
+  ## Control structure fields are:
+  ## Current properties are:
+  ## @table @asis
+  ## @item out
+  ## Out bit in the control register
+  ## @item sqwe
+  ## Square wave enable bit in control register
+  ## @item rs
+  ## The combined RS0, RS1 value
+  ## @end table
+  ##
+  ## @end deftypefn
+  ##
+  ## @deftypefn {} {@var{YN} =} isstarted(@var{dsObj})
+  ## Get whether the RTC clock is currently counting time
+  ##
+  ## @subsubheading Inputs
+  ## @var{dsObj} - the ds1307 object
+  ##
+  ## @subsubheading Outputs
+  ## @var{YN} - returns true if the RTC is counting
+  ##
+  ## @seealso{start, stop}
+  ## @end deftypefn
+  ##
+  ## @deftypefn {} {} start(@var{dsObj})
+  ## Start the RTC counting
+  ##
+  ## @subsubheading Inputs
+  ## @var{dsObj} - the ds1307 object
+  ##
+  ## @subsubheading Outputs
+  ## None
+  ##
+  ## @seealso{datevec}
+  ## @end deftypefn
+  ##
+  ## @deftypefn {} {} stop(@var{dsObj})
+  ## Stop the RTC counting
+  ##
+  ## @subsubheading Inputs
+  ## @var{dsObj} - the ds1307 object
+  ##
+  ## @subsubheading Outputs
+  ## None
+  ##
+  ## @seealso{datevec}
+  ## @end deftypefn
+
   properties(Access = private)
     i2c;
 
@@ -240,7 +240,22 @@ classdef DS1307 < handle
     function display(this)
       printf("%s = \n", inputname(1));
       printf("    %s with properties\n", class(this));
-      printf("        I2C Address = 0x%X\n", this.i2c.address);
+      if isobject(this.i2c)
+        printf("        I2C Address = 0x%X\n", this.i2c.i2caddress);
+      else
+        printf("        Not connected");
+      endif
+    endfunction
+
+    function delete(this)
+      try
+	if isobject(this.i2c)
+	  delete(this.i2c);
+	  this.i2c = [];
+	endif
+      catch
+        # do nothing
+      end_try_catch
     endfunction
 
   endmethods
